@@ -1,5 +1,4 @@
 <?php
-include_once ULICMS_ROOT . "/templating.php";
 
 define("MODULE_ADMIN_HEADLINE", "XML Sitemap");
 
@@ -56,15 +55,15 @@ function generate_sitemap()
         if (! startsWith($row->redirection, "#")) {
             
             $xml_string .= "<url>\r\n";
-            $xml_string .= "\t<loc>" . xmlspecialchars(getBaseURL($row->language) . $row->systemname . ".html") . "</loc>\r\n";
+            $xml_string .= "\t<loc>" . xmlspecialchars(getBaseURL($row->language) . $row->slug . ".html") . "</loc>\r\n";
             $xml_string .= "\t<lastmod>" . date("Y-m-d", $row->lastmodified) . "</lastmod>\r\n";
             $xml_string .= "</url>\r\n\r\n";
             
-            if (containsModule($row->systemname, "blog")) {
+            if (containsModule($row->slug, "blog")) {
                 $query_blog = db_query("SELECT * FROM " . tbname("blog") . " WHERE entry_enabled = 1 AND language='" . $row->language . "' ORDER by datum DESC");
                 while ($row2 = db_fetch_object($query_blog)) {
                     $xml_string .= "<url>\r\n";
-                    $xml_string .= "\t<loc>" . xmlspecialchars(getBaseURL($row->language) . $row->systemname . ".html?single=" . $row2->seo_shortname) . "</loc>\r\n";
+                    $xml_string .= "\t<loc>" . xmlspecialchars(getBaseURL($row->language) . $row->slug . ".html?single=" . $row2->seo_shortname) . "</loc>\r\n";
                     $xml_string .= "\t<lastmod>" . date("Y-m-d", $row2->datum) . "</lastmod>\r\n";
                     $xml_string .= "</url>\r\n\r\n";
                 }
@@ -81,11 +80,17 @@ function generate_sitemap()
     $xml_file = ULICMS_DATA_STORAGE_ROOT . "/sitemap.xml";
     
     $url = defined("ULICMS_DATA_STORAGE_URL") ? ULICMS_DATA_STORAGE_URL . "/sitemap.xml" : "../sitemap.xml";
-    
+	
+	    
     $handle = @fopen($xml_file, "w");
     if ($handle) {
         fwrite($handle, $xml_string);
         fclose($handle);
+		
+		$xml_sitemap_url = Settings::get("xml_sitemap_url");
+		if($xml_sitemap_url){
+			file_get_contents_wrapper("https://google.com/ping?sitemap=".urlencode($xml_sitemap_url), true);
+		}
         
         translate("GENERATE_XML_SITEMAP_SUCCESS", array(
             "%url%" => $url
@@ -112,7 +117,7 @@ function xml_sitemap_admin()
     
     csrf_token_html();
     ?>
-<button type="submit" name="submit" class="btn btn-success"><?php translate("generate_xml_sitemap");?></button>
+<button type="submit" name="submit" class="btn btn-success"><i class="fas fa-sitemap"></i> <?php translate("generate_xml_sitemap");?></button>
 </form>
 <?php
 }
